==> haskell-ansi-wl-pprint-0.6.9-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-wl-pprint
version:              0.6.9
visibility:           public
id:                   ansi-wl-pprint-0.6.9-E9FfrHfMGqZ6CjdG4mGL9g
key:                  ansi-wl-pprint-0.6.9-E9FfrHfMGqZ6CjdG4mGL9g
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  6c0049b628b5722b0f30e877ecef0b57
exposed:              True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/ansi-wl-pprint-0.6.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ansi-wl-pprint-0.6.9
hs-libraries:         HSansi-wl-pprint-0.6.9-E9FfrHfMGqZ6CjdG4mGL9g
depends:
    ansi-terminal-0.10.3-2hRHpdP0mYi9hgBbVJ74wT base-4.14.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.9-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-wl-pprint
version:              0.6.9
visibility:           public
id:                   ansi-wl-pprint-0.6.9-DKuIRoJ9gnj7LTSIjeYDjE
key:                  ansi-wl-pprint-0.6.9-DKuIRoJ9gnj7LTSIjeYDjE
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  722098817cee7391830fb1e902247865
exposed:              True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/ansi-wl-pprint-0.6.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ansi-wl-pprint-0.6.9
hs-libraries:         HSansi-wl-pprint-0.6.9-DKuIRoJ9gnj7LTSIjeYDjE
depends:
    ansi-terminal-0.10.3-BPHE8l4o9A6EvDiT7QnwTU base-4.14.1.0

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
